==> claws-mail-3.8.0-ldap.tgz: include/claws-mail/gtk/authors.h <==
static char *TEAM_LIST[] = {
"Holger Berndt <berndth@users.sf.net>",
"Tristan Chabredier <wwp@claws-mail.org>",
"Hoà Viêt Dinh <hoa@users.sf.net>",
"Andrej Kacian <andrej@kacian.sk>",
"Darko Koruga <darko@users.sf.net>",
"Ricardo Mones Lastra <ricardo@mones.org>",
"Colin Leroy <colin@colino.net>",
"Paul Mangan <paul@claws-mail.org>",
"Salvatore De Paolis <iwkse@claws-mail.org>",
"Paweł Pękala <c0rn@o2.pl>",
"Michael Rasmussen <mir@datanom.net>",
NULL
};

static char *EX_TEAM_LIST[] = {
"Keith Edmunds",
"Match Grun",
"Melvin Hadasht",
"Oliver Haertel",
"Christoph Hohmann",
"Alfons Hoogervorst",
"Werner Koch",
"Thorsten Maerz",
"Leandro A. F. Pereira",
"Luke Plant",
"Martin Schaaf",
"Carsten Schurig",
"Fabien Vantard",
"Sergey Vlasov",
"Hiroyuki Yamamoto",
NULL
};

static char *TRANS_TEAM_LIST[] = {
"[bg] Yasen Pramatarov <yasen@lindeas.com>",
"[ca] Miquel Oliete <ktalanet@yahoo.es>",
"[cs] David Vachulka <david@konstrukce-cad.com>",
"[de] Stephan Sachse <white@dev-zero.com>",
"[en_GB] Paul Mangan <paul@claws-mail.org>",
"[es] Ricardo Mones Lastra <ricardo@mones.org>",
"[fi] Flammie Pirinen <flammie@iki.fi>",
"[fr] Colin Leroy <colin@colino.net>",
"[hu] Páder Rezső <rezso@rezso.net>",
"[id] MSulchan Darmawan <bleketux@gmail.com>",
"[it] Andrea Spadaccini <a.spadaccini@catania.linux.it>",
"[ja] kazken3 <kazken3@gmail.com>",
"[lt] Mindaugas Baranauskas <embar@super.lt>",
"[nl] Marcel Pol <mpol@gmx.net>",
"[pl] Emilian Nowak <emil5@go2.pl>",
"[pt_BR] Frederico Goncalves Guimaraes <fggdebian@yahoo.com.br>",
"[pt_PT] Tiago Faria <gouki@goukihq.org>",
"[ru] Aleksei Miheev <aleksei@miheev.info>",
"[sk] Slavko <slavino@slavino.sk>",
"[sv] Lars Persson Fink <lars.p.fink@gmail.com>",
"[uk] YUP <yupadmin@gmail.com>",
"[zh_CN] Ralgh Young <bamanzi@gmail.com>",
NULL
};

static char *DOC_TEAM_LIST[] = {
"[en] Tristan Chabredier <wwp@claws-mail.org>",
"     Ricardo Mones Lastra <ricardo@mones.org>",
"     Colin Leroy <colin@colino.net>",
"     Paul Mangan <paul@claws-mail.org>",
"[de] Volker Ribbert <thoraki@arcor.de>",
"[es] Ricardo Mones Lastra <ricardo@mones.org>",
"[fr] Tristan Chabredier <wwp@claws-mail.org>",
"     Colin Leroy <colin@colino.net>",
"[pl] Paweł Pękala <c0rn@gazeta.pl>",
NULL
};

static char *LOGO_LIST[] = {
"Jesper Schultz <jesper@schultz-net.dk>",
NULL
};

static char *ICONS_LIST[] = {
"Jakub 'jimmac' Steiner <jimmac@ximian.com>",
"Aleksandar Urosevic <urke@users.sf.net>",
NULL
};

static char *CONTRIBS_LIST[] = {
"Alte",
"Jeremy Andrews",
"Stephen Anthony",
"Sergei Astanin",
"Ruslan N. Balkin",
"Fabio Junior Beneditto",
"M. Benkmann",
"Wilbert Berendsen",
"Didier Barvaux",
"Sébastien Bigaret",
"Laurent Bigonville",
"Jean-Luc Biord",
"Pavlo Bohmat",
"Eugene Brevdo",
"André Filipe de Assunção e Brito",
"Henrik Carlqvist",
"Luca Cavalli",
"David Chalmers",
"Wei-Lun Chao",
"Guillaume Chazarain",
"Tsu-Fan Cheng",
"Manrat Chobchuen",
"Rich Coe",
"Jonathan Corbet",
"Christian Cornelssen",
"George Danchev",
"Matthieu Dazy",
"Pierric Descamps",
"Frank Dietrich",
"Tim Dijkstra",
"Nicolas Doualot",
"Felix Eckhofer",
"Charles A. Edwards",
"Stefaan Eeckels",
"Mikhail Efremov",
"Willem van Engen",
"Paul Evans",
"Leonid Evdokimov",
"Xavier FACQ",
"Bob Forsman",
"Matthias Förste",
"Stoyan Genov",
"Stavros Giannouris",
"Thomas Gilgin",
"Marius Glauser",
"Thierry Godefroy",
"Alex Gorbachenko",
"Bodo Graumann",
"Yang Guilong",
"Daniel Gustafson",
"HIROSHIMA",
"Oliver Haertel",
"Anders Hammar",
"Mitko Haralanov",
"Hashimoto",
"Jacob Head",
"Federico Heinz",
"Geir Helland",
"Jorge Van Hemelryck",
"Higuchi",
"Hiramatu",
"Marc Hoper",
"Michihide Hotta",
"Shawn Houston",
"Michael Hughes",
"Chideok Hwang",
"John E.P. Hynes",
"Hironori IWANE",
"Motonobu Ichimura",
"Alexey Illarionov",
"Yoichi Imai",
"Mathias Intemann",
"Ishihara",
"Jens Jahnke",
"Pascal Jermini",
"KAJIWARA",
"KUROSAWA",
"Nicolas Kaiser",
"Stanislav Karchebny",
"WAKAI Kazunao",
"Fabian Keil",
"Martin Kluge",
"IWAMOTO Kouichi",
"Joshua M. Kwan",
"Jean-Yves Lefort",
"Jérôme Lelong",
"Eric Limpens",
"Thomas Link",
"Reed Loden",
"David Looney",
"Alessandro Maestri",
"Maki",
"Jindrich Makovicka",
"Tim Mann",
"Ivan Francolin Martinez",
"HIRAMATSU Masami",
"Yasuzaki Masayoshi",
"Jason McCarver",
"Yotam Medini",
"David Mehrmann",
"Christian Mertes",
"Bram Metsch",
"Hanno Meyer-Thurow",
"George Michaelson",
"Florian Mickler",
"Neill Miller",
"Suzuki Mio",
"Alex S Moore",
"NAKAGAWA",
"Yuuki NINOMIYA",
"Satoshi Nagayasu",
"Yukihiro Nakai",
"SungHyun Nam",
"OSHIRO Naoki",
"Andrew Nelson",
"Nishika",
"Nishimura",
"Nishiyama",
"Masaaki Noro",
"Ales Nosek",
"James Noyes",
"Jens Oberender",
"Ofer",
"Ohmasa",
"Paul Ollis",
"Fredrik Olofssen",
"Reza Pakdel",
"Martin Pool",
"Quar",
"Don Quijote",
"Steve Rader",
"Jens Rantil",
"Ravemax",
"Ivan Rayner",
"David Relson",
"Chad Robinson",
"Paul Rolland",
"Luca Rosellini",
"Guy Rouillier",
"Stephan Sachse",
"Sakamoto",
"Mohammed Sameer",
"Tobias Sandhaas",
"Torsten Schoenfeld",
"Simon 'corecode' Schubert",
"Kim Schulz",
"Markus Schwarzenberg",
"Rodrigo Dias Arruda Senra",
"Setoh",
"shigeri",
"Gustavo Noronha Silva",
"Jesse Skinner",
"Ville Skyttä",
"Dale P. Smith",
"Bogdan Sumanariu",
"TAKANO",
"TOGAWA",
"Tajiri",
"Takahashi",
"Tanaka",
"Shimamoto \"Neko\" Tatsuya",
"Pascal Terjan",
"Thorsten Thielen",
"Edgar Toernig",
"Masahiro Tomita",
"Tomita",
"Topia",
"Anders Troback",
"Tsutsui",
"Aleksandar Urosevic",
"Petr Vanek",
"Jeroen Versteeg",
"Kevin Vigor",
"Botalov Vyacheslav",
"Radek Vybiral",
"Jonathan Ware",
"Watanabe",
"Rafal Weglarz",
"Martin Wicke",
"Bob Woodside",
"YAMAGUCHI",
"T. Yamamoto",
"Yanase",
"Yasumatsu",
"Ralgh Young",
"Gál Zoltán",
"Marien Zwart",
"Martin Zwickel",
NULL
};

==> claws-mail-3.17.4-ldap.tgz: include/claws-mail/gtk/authors.h <==
static char *TEAM_LIST[] = {
"Holger Berndt <berndth@users.sf.net>",
"Tristan Chabredier <wwp@claws-mail.org>",
"Andrej Kacian <andrej@kacian.sk>",
"Darko Koruga <darko@users.sf.net>",
"Charles Lehner <charles@claws-mail.org>",
"Colin Leroy-Mira <colin@colino.net>",
"Paul Mangan <paul@claws-mail.org>",
"Ricardo Mones Lastra <ricardo@mones.org>",
"Salvatore De Paolis <iwkse@claws-mail.org>",
"Paweł Pękala <c0rn@o2.pl>",
"Michael Rasmussen <mir@datanom.net>",
NULL
};

static char *EX_TEAM_LIST[] = {
"Hoà Viêt Dinh",
"Keith Edmunds",
"Match Grun",
"Melvin Hadasht",
"Oliver Haertel",
"Christoph Hohmann",
"Alfons Hoogervorst",
"Werner Koch",
"Thorsten Maerz",
"Leandro A. F. Pereira",
"Luke Plant",
"Martin Schaaf",
"Carsten Schurig",
"Fabien Vantard",
"Sergey Vlasov",
"Hiroyuki Yamamoto",
NULL
};

static char *TRANS_TEAM_LIST[] = {
"[ca] David Medina <opensusecatala@gmail.com>",
"[cs] David Vachulka <david@konstrukce-cad.com>",
"[da] Erik P. Olsen <epodata@gmail.com>",
"[de] Simon Legner <simon.legner@gmail.com>",
"[en_GB] Paul Mangan <paul@claws-mail.org>",
"[es] Ricardo Mones Lastra <ricardo@mones.org>",
"[fi] Flammie Pirinen <flammie@iki.fi>",
"[fr] Tristan Chabredier <wwp@claws-mail.org>",
"[hu] Páder Rezső <rezso@rezso.net>",
"[id_ID] MSulchan Darmawan <bleketux@gmail.com>",
"[it] Luigi Votta <luigi.vtt@gmail.com>",
"[ja] UTUMI Hirosi <utuhiro78@yahoo.co.jp>",
"[nb] Petter Adsen <petter@synth.no>",
"[nl] Marcel Pol <mpol@gmx.net>",
"[pl] Jakub Jankiewicz <jcubic@jcubic.pl>",
"[pt_BR] Frederico Goncalves Guimaraes <frederico@teia.bio.br>",
"[pt_PT] Pedro Albuquerque <palbuquerque73@gmail.com>",
"[ro] Cristian Secară <liste@secarica.ro>",
"[ru] Mikhail Kurinnoi <viewizard@viewizard.com>",
"[sk] Slavko <slavino@slavino.sk>",
"[sv] Andreas Rönnquist <gusnan@openmailbox.org>",
"[tr] Numan Demirdöğen <if.gnu.linux@gmail.com>",
"[zh_TW] Mark Chang <mark.cyj@gmail.com>",
NULL
};

static char *DOC_TEAM_LIST[] = {
"[en] Tristan Chabredier <wwp@claws-mail.org>",
"     Ricardo Mones Lastra <ricardo@mones.org>",
"     Colin Leroy <colin@colino.net>",
"     Paul Mangan <paul@claws-mail.org>",
"[es] Ricardo Mones Lastra <ricardo@mones.org>",
"[fr] Tristan Chabredier <wwp@claws-mail.org>",
"     Colin Leroy <colin@colino.net>",
"[pl] Paweł Pękala <c0rn@gazeta.pl>",
NULL
};

static char *LOGO_LIST[] = {
"Jesper Schultz <jesper@schultz-net.dk>",
NULL
};

static char *ICONS_LIST[] = {
"Jakub 'jimmac' Steiner <jimmac@ximian.com>",
"Aleksandar Urošević <urke@users.sf.net>",
NULL
};

static char *CONTRIBS_LIST[] = {
"Alte",
"Jeremy Andrews",
"Stephen Anthony",
"André Filipe de Assunção e Brito",
"Sergei Astanin",
"Ruslan N. Balkin",
"Andy Balaam",
"Henri Bauer",
"Didier Barvaux",
"Fabio Júnior Beneditto",
"M. Benkmann",
"Wilbert Berendsen",
"Sébastien Bigaret",
"Laurent Bigonville",
"Jean-Luc Biord",
"Blatinox",
"Hanno Boeck",
"Pavlo Bohmat",
"Ralf Bormann",
"H. Merijn Brand",
"Eugene Brevdo",
"Olivier Brunel",
"Sean Buckheister",
"Anton Butanaev",
"Henrik Carlqvist",
"Luca Cavalli",
"David Chalmers",
"Wei-Lun Chao",
"Guillaume Chazarain",
"Tsu-Fan Cheng",
"Manrat Chobchuen",
"Rich Coe",
"Natanael Copa",
"Jonathan Corbet",
"Christian Cornelssen",
"Palmer Dabbelt",
"George Danchev",
"Robert David",
"Kevin Day",
"Matthieu Dazy",
"Ben Deering",
"Pierric Descamps",
"Rodrigo Dias Arruda Senra",
"Frank Dietrich",
"Tim Dijkstra",
"Nicolas Doualot",
"Felix Eckhofer",
"Charles A. Edwards",
"Stefaan Eeckels",
"Mikhail Efremov",
"Willem van Engen",
"Paul Evans",
"Leonid Evdokimov",
"Xavier FACQ",
"Tiago Faria",
"Alessandro Di Federico",
"Lars Persson Fink",
"Bob Forsman",
"Matthias Förste",
"Ivan Francolin Martinez",
"Stoyan Genov",
"Stavros Giannouris",
"Thomas Gilgin",
"Marius Glauser",
"Michael Gmelin",
"Thierry Godefroy",
"Alex Gorbachenko",
"Michał Górny",
"Bodo Graumann",
"Yang Guilong",
"Ashish Gupta",
"Daniel Gustafson",
"HIROSHIMA",
"Oliver Haertel",
"Anders Hammar",
"Mitko Haralanov",
"Hashimoto",
"Jacob Head",
"Federico Heinz",
"Geir Helland",
"Jorge Van Hemelryck",
"Olaf Hering",
"Christian Hesse",
"Higuchi",
"Hiramatu",
"Marc Hoper",
"Michihide Hotta",
"Shawn Houston",
"Michael Hughes",
"Richard Hughes",
"Arthur Huillet",
"Ben Hutchings",
"Chideok Hwang",
"John E.P. Hynes",
"Hironori IWANE",
"Motonobu Ichimura",
"Alexey Illarionov",
"Yoichi Imai",
"Mathias Intemann",
"Ishihara",
"Jens Jahnke",
"Daniel Jakots",
"Pascal Jermini",
"KAJIWARA",
"KUROSAWA",
"Nicolas Kaiser",
"Stanislav Karchebny",
"kazken3",
"WAKAI Kazunao",
"Fabian Keil",
"Martin Kluge",
"IWAMOTO Kouichi",
"Mikhail Kurinnoi",
"Abhay S. Kushwaha",
"Joshua M. Kwan",
"Jean-Yves Lefort",
"Flavio Leitner",
"Jérôme Lelong",
"Eric Limpens",
"Thomas Link",
"Reed Loden",
"David Looney",
"Alessandro Maestri",
"Maki",
"Jindrich Makovicka",
"Igor Mammedov",
"Tim Mann",
"Darac Marjal",
"HIRAMATSU Masami",
"Yasuzaki Masayoshi",
"Jason McCarver",
"Yotam Medini",
"David Mehrmann",
"Christian Mertes",
"Bram Metsch",
"Hanno Meyer-Thurow",
"George Michaelson",
"Florian Mickler",
"Neill Miller",
"Suzuki Mio",
"Alex S Moore",
"NAKAGAWA",
"Yuuki NINOMIYA",
"Satoshi Nagayasu",
"Yukihiro Nakai",
"SungHyun Nam",
"OSHIRO Naoki",
"Andrew Nelson",
"Nishika",
"Nishimura",
"Nishiyama",
"Masaaki Noro",
"Gustavo Noronha Silva",
"Ales Nosek",
"Emilian Nowak",
"James Noyes",
"Jens Oberender",
"Ofer",
"Ohmasa",
"Miquel Oliete",
"Paul Ollis",
"Fredrik Olofssen",
"Orbea",
"Thomas Orgis",
"Reza Pakdel",
"Richard Palo",
"Marcel Pol",
"Martin Pool",
"Quar",
"Don Quijote",
"Steve Rader",
"Jens Rantil",
"Ravemax",
"Eric S. Raymond",
"Ivan Rayner",
"David Relson",
"Volker Ribbert",
"Chad Robinson",
"Paul Rolland",
"Andreas Rönnquist",
"Luca Rosellini",
"Guy Rouillier",
"Stephan Sachse",
"Sakamoto",
"Mohammed Sameer",
"Tobias Sandhaas",
"Peter Sarvas",
"Oliver Schneider",
"Torsten Schoenfeld",
"Simon 'corecode' Schubert",
"Kim Schulz",
"Markus Schwarzenberg",
"Michael Schwendt",
"Ralph Sennhauser",
"Setoh",
"Michael Shell",
"shigeri",
"Jesse Skinner",
"Ville Skyttä",
"Alex Smith",
"Dale P. Smith",
"Avinash Sonawane",
"Andrea Spadaccini",
"Bogdan Sumanariu",
"TAKANO",
"TOGAWA",
"Tajiri",
"Takahashi",
"Tanaka",
"Shimamoto \"Neko\" Tatsuya",
"Timo Teräs",
"Pascal Terjan",
"Thorsten Thielen",
"Edgar Toernig",
"Masahiro Tomita",
"Tomita",
"Topia",
"Anders Troback",
"Tsutsui",
"Aleksandar Urošević",
"Petr Vanek",
"Jeroen Versteeg",
"Kevin Vigor",
"Michael Vilain",
"Johan Vromans",
"Botalov Vyacheslav",
"Radek Vybiral",
"Jonathan Ware",
"Watanabe",
"Rafal Weglarz",
"Martin Wicke",
"Bob Woodside",
"YAMAGUCHI",
"T. Yamamoto",
"Yanase",
"Yasumatsu",
"Ralgh Young",
"YUP",
"Daniel Zaoui",
"Gál Zoltán",
"Marien Zwart",
"Martin Zwickel",
NULL
};
